==> p2.ui-0.2.2-py3-none-any.whl: p2/ui/app.py <==
import os
import msal
import requests
import uuid

from flask import Flask, render_template, abort, jsonify, session, url_for, request, redirect
# from flask_session import Session  # https://pythonhosted.org/Flask-Session
from flask_cors import CORS

from p2.ui import settings
from p2.ui.core import Core

app = Flask(__name__)
core = Core()

app.config.from_object(settings)
# Session(app)

# This section is needed for url_for("foo", _external=True) to automatically
# generate http scheme when this sample is running on localhost,
# and to generate https scheme when it is deployed behind reversed proxy.
# See also https://flask.palletsprojects.com/en/1.0.x/deploying/wsgi-standalone/#proxy-setups
from werkzeug.middleware.proxy_fix import ProxyFix
app.wsgi_app = ProxyFix(app.wsgi_app, x_proto=1, x_host=1)

tenant_id = os.getenv("TENANT_ID")
if tenant_id is None:
    raise Exception("No TENANT_ID defined")
authority = f"{settings.AUTHORITY}/{tenant_id}"


client_id = os.getenv("CLIENT_ID")
if client_id is None:
    raise Exception("No CLIENT_ID defined")

@app.route('/api/js')
def js():
    return jsonify(core.get_js())

@app.route('/api/css')
def css():
    return jsonify(core.get_css())

@app.route('/')
def index():
    if not session.get("user"):
        return redirect(url_for("login"))

    data = {
        'js_files': core.get_js(),
        'css_files': core.get_css(),
        'menubar': core.get_menubar() or []
    }
    return render_template('main.html', user=session["user"], **data)

@app.route("/login")
def login():
    session["state"] = str(uuid.uuid4())


    auth_url = _build_auth_url(
        scopes    = settings.DELEGATED_PERMISSIONS,
        state     = session["state"])

    data = {
        'js_files': core.get_js(),
        'css_files': core.get_css(),
        'menubar': core.get_menubar() or []
    }
    return render_template('main.html', auth_url=auth_url, **data)


@app.route("/logout")
def logout():
    session.clear()  # Wipe out user and its token cache from session
    return redirect(  # Also logout from your tenant's web session
        authority + "/oauth2/v2.0/logout" +
        "?post_logout_redirect_uri=" + url_for("index", _external=True))


@app.route('/api/app-menu')
def appMenu():
    appMenu=list()
    for service in settings.REGISTERED_APPS:
        resp = requests.get(f"http://localhost:5000/{service}/menu")
        appMenu.append(resp.json())
    return jsonify(appMenu)

@app.route(settings.REDIRECT_PATH)
def authorized():
    if request.args.get('code'):
        cache = _load_cache()
        result = _build_msal_app(cache=cache).acquire_token_by_authorization_code(
            request.args['code'],
            scopes=settings.DELEGATED_PERMISSIONS,
            redirect_uri=url_for("authorized", _external=True))
        if "error" in result:
            return render_template("auth_error.html", result=result)
        session["user"] = result.get("id_token_claims")
        _save_cache(cache)

    data = {
        'js_files': core.get_js(),
        'css_files': core.get_css(),
        'menubar': core.get_menubar(),
        'user': session.get('user')
    }
    return render_template('main.html', **data)

#----- utility functions
def _load_cache():
    cache = msal.SerializableTokenCache()
    if session.get("token_cache"):
        cache.deserialize(session["token_cache"])
    return cache

def _save_cache(cache):
    if cache.has_state_changed:
        session["token_cache"] = cache.serialize()

def _build_msal_app(cache=None):
    return msal.ConfidentialClientApplication(
        client_id=client_id,
        authority=authority,
        client_credential=os.getenv('CLIENT_SECRET', ''),
        token_cache=cache,
        verify=False
    )

def _build_auth_url(scopes=None, state=None):
    return _build_msal_app().get_authorization_request_url(
        scopes or [],
        state=state or str(uuid.uuid4()),
        redirect_uri=url_for("authorized", _external=True))

if __name__ == '__main__':
    app.run()

==> p2.ui-0.4.5-py3-none-any.whl: p2/ui/app.py <==
import os
import msal
import requests
import uuid
import logging
from pprint import pformat

from flask import Flask, render_template, abort, jsonify, session, url_for, request, redirect
from flask_session import Session  # https://pythonhosted.org/Flask-Session
from flask_cors import CORS

from p2.ui import settings
from p2.ui.core import Core

app = Flask(__name__)
CORS(app)
app.logger.setLevel(logging.DEBUG)
core = Core()

app.config.from_object(settings)
Session(app)

# This section is needed for url_for("foo", _external=True) to automatically
# generate http scheme when this sample is running on localhost,
# and to generate https scheme when it is deployed behind reversed proxy.
# See also https://flask.palletsprojects.com/en/1.0.x/deploying/wsgi-standalone/#proxy-setups
from werkzeug.middleware.proxy_fix import ProxyFix
app.wsgi_app = ProxyFix(app.wsgi_app, x_proto=1, x_host=1)

tenant_id = os.getenv("TENANT_ID")
if tenant_id is None:
    raise Exception("No TENANT_ID defined")
authority = f"{settings.AUTHORITY}/{tenant_id}"

client_id = os.getenv("CLIENT_ID")
if client_id is None:
    raise Exception("No CLIENT_ID defined")

@app.route('/api/js')
def js():
    return jsonify(core.get_js())

@app.route('/api/css')
def css():
    return jsonify(core.get_css())

@app.route('/')
def index():
    session["state"] = str(uuid.uuid4())
    auth_url = _build_auth_url(
        scopes    = settings.DELEGATED_PERMISSIONS,
        state     = session["state"])

    app.logger.debug('[/]: auth_url: %s', auth_url)
    data = {
        'js_files': core.get_js(),
        'css_files': core.get_css(),
        'menubar': core.get_menubar() or [],
        'user': session.get('user'),
        'auth_url': auth_url
    }
    return render_template('main.html', **data)

@app.route("/logout")
def logout():
    session.clear()  # Wipe out user and its token cache from session
    redirect_url = url_for("index", _external=True)
    app.logger.debug("[/logout]: Redirect url: %s", redirect_url)
    return redirect(authority + "/oauth2/v2.0/logout" + "?post_logout_redirect_uri=" + redirect_url)

@app.route(settings.REDIRECT_PATH)
def authorized():
    if request.args.get('code'):
        cache = _load_cache()
        redirect_url=url_for("authorized", _external=True)
        app.logger.debug("[/getToken]: Redirect url: %s", redirect_url)
        result = _build_msal_app(cache=cache).acquire_token_by_authorization_code(
            request.args['code'],
            scopes=settings.DELEGATED_PERMISSIONS,
            redirect_uri=redirect_url
        )
        app.logger.debug('[/getToken]: result: %s', pformat(result))
        if "error" in result:
            return render_template("auth_error.html", result=result)
        session["user"] = result.get("id_token_claims")
        _save_cache(cache)

    data = {
        'js_files': core.get_js(),
        'css_files': core.get_css(),
        'menubar': core.get_menubar(),
        'user': session['user']
    }
    return render_template('main.html', **data)

#----- utility functions
def _load_cache():
    cache = msal.SerializableTokenCache()
    if session.get("token_cache"):
        cache.deserialize(session["token_cache"])
    return cache

def _save_cache(cache):
    if cache.has_state_changed:
        session["token_cache"] = cache.serialize()

def _build_msal_app(cache=None):
    return msal.ConfidentialClientApplication(
        client_id=client_id,
        authority=authority,
        client_credential=os.getenv('CLIENT_SECRET', ''),
        token_cache=cache,
        verify=False
    )

def _build_auth_url(scopes=None, state=None):
    redirect_url=url_for("authorized", _external=True)
    app.logger.debug("[_build_auth_url]: Redirect url: %s", redirect_url)
    return _build_msal_app().get_authorization_request_url(
        scopes or [],
        state=state or str(uuid.uuid4()),
        redirect_uri=redirect_url
    )

if __name__ == '__main__':
    app.run()
